aboutsummaryrefslogtreecommitdiff
path: root/google/ads/googleads/v1/resources/shopping_performance_view.proto
diff options
context:
space:
mode:
Diffstat (limited to 'google/ads/googleads/v1/resources/shopping_performance_view.proto')
-rw-r--r--google/ads/googleads/v1/resources/shopping_performance_view.proto4
1 files changed, 2 insertions, 2 deletions
diff --git a/google/ads/googleads/v1/resources/shopping_performance_view.proto b/google/ads/googleads/v1/resources/shopping_performance_view.proto
index 7de63dea4..c7d022552 100644
--- a/google/ads/googleads/v1/resources/shopping_performance_view.proto
+++ b/google/ads/googleads/v1/resources/shopping_performance_view.proto
@@ -43,11 +43,11 @@ message ShoppingPerformanceView {
pattern: "customers/{customer}/shoppingPerformanceView"
};
// Immutable. The resource name of the Shopping performance view.
// Shopping performance view resource names have the form:
// `customers/{customer_id}/shoppingPerformanceView`
string resource_name = 1 [
- (google.api.field_behavior) = IMMUTABLE,
+ (google.api.field_behavior) = OUTPUT_ONLY,
(google.api.resource_reference) = {
type: "googleads.googleapis.com/ShoppingPerformanceView"
}
@@ -43,11 +43,11 @@ message ShoppingPerformanceView {
pattern: "customers/{customer}/shoppingPerformanceView"
};
- // Immutable. The resource name of the Shopping performance view.
+ // Output only. The resource name of the Shopping performance view.
// Shopping performance view resource names have the form:
// `customers/{customer_id}/shoppingPerformanceView`